@@ -44,13 +44,14 @@ The C<tests> tag will be replaced by the actual testing code.
 =cut
 
 use strict;
-use base 'Test::Inline::Content';
 use File::Slurp  ();
 use Params::Util qw{_INSTANCE};
+use Test::Inline::Content ();
 
-use vars qw{$VERSION};
+use vars qw{$VERSION @ISA};
 BEGIN {
-	$VERSION = '2.209';
+	$VERSION = '2.210';
+	@ISA     = 'Test::Inline::Content';
 }
 
 
